@@ -37,7 +37,7 @@
 	if(optimcontrol$method=="discrete"){
 		if (is.null(optimcontrol$optim.points)){
 			n.discrete.points<-d*100
-			optimcontrol$optim.points <- lower + matrix(runif(d*n.discrete.points),ncol=d) * (upper - lower)
+			optimcontrol$optim.points <- t(lower + t(matrix(runif(d*n.discrete.points),ncol=d)) * (upper - lower))
 		}
 		optim.points <- optimcontrol$optim.points
 		optim.points <- data.frame(optim.points)
@@ -70,8 +70,6 @@
 	#Optimization with Genoud
 	if(optimcontrol$method=="genoud"){
 		
-		#save environment here for the gradient calculation ?
-		
 		if (is.null(optimcontrol$pop.size))  optimcontrol$pop.size <- 50*d#floor(4 + 3 * log(d))
 		if (is.null(optimcontrol$max.generations))  optimcontrol$max.generations <- 10*d#100*d
 		if (is.null(optimcontrol$wait.generations))  optimcontrol$wait.generations <- 2#2
@@ -79,7 +77,8 @@
 		if (is.null(optimcontrol$parinit))  optimcontrol$parinit <- NULL
 		if (is.null(optimcontrol$unif.seed))  optimcontrol$unif.seed <- 1
 		if (is.null(optimcontrol$int.seed))  optimcontrol$int.seed <- 1
-		
+		if (is.null(optimcontrol$print.level))  optimcontrol$print.level <- 1
+    
 		#mutations
 		if (is.null(optimcontrol$P1)) optimcontrol$P1<-0#50		#copy
 		if (is.null(optimcontrol$P2)) optimcontrol$P2<-0#50
@@ -99,7 +98,7 @@
 				Domains=domaine, default.domains=10, solution.tolerance=0.000000001,
 				boundary.enforcement=2, lexical=FALSE, gradient.check=FALSE, BFGS=TRUE,
 				data.type.int=FALSE, hessian=FALSE, unif.seed=optimcontrol$unif.seed, 
-				int.seed=optimcontrol$int.seed,print.level=1, share.type=0, instance.number=0,
+				int.seed=optimcontrol$int.seed,print.level=optimcontrol$print.level, share.type=0, instance.number=0,
 				output.path="stdout", output.append=FALSE, project.path=NULL,
 				P1=optimcontrol$P1, P2=optimcontrol$P2, P3=optimcontrol$P3, 
 				P4=optimcontrol$P4, P5=optimcontrol$P5, P6=optimcontrol$P6,
